Package: rsdmx
Version: 0.6-5
Date: 2025-02-27
Title: Tools for Reading SDMX Data and Metadata
Authors@R: c(
  person("Emmanuel", "Blondel", role = c("aut", "cre"), email = "emmanuel.blondel1@gmail.com", comment = c(ORCID = "0000-0002-5870-5762")),
  person("Matthieu", "Stigler", role = c("ctb"), comment =c(ORCID="0000-0002-6802-4290")),
  person("Eric", "Persson", role = c("ctb")))
Maintainer: Emmanuel Blondel <emmanuel.blondel1@gmail.com>
Depends: R (>= 2.15)
Imports: R6, methods, XML (>= 3.98-1.3), httr, plyr, utils
Suggests: testthat, knitr, roxygen2, markdown
Description: Set of classes and methods to read data and metadata documents
  exchanged through the Statistical Data and Metadata Exchange (SDMX) framework,
  currently focusing on the SDMX XML standard format (SDMX-ML).
License: GPL (>= 2)
VignetteBuilder: knitr
URL: https://github.com/opensdmx/rsdmx, https://sdmx.org
BugReports: https://github.com/opensdmx/rsdmx/issues
LazyLoad: yes
Encoding: UTF-8
Collate: rsdmx_logger.R Class-SDMXSchema.R Class-SDMXType.R
        Class-SDMXStructureType.R Class-SDMXHeader.R
        Class-SDMXFooterMessage.R Class-SDMXFooter.R Class-SDMX.R
        Class-SDMXConcept.R Class-SDMXConceptScheme.R
        Class-SDMXConcepts.R Class-SDMXCode.R Class-SDMXCodelist.R
        Class-SDMXCodelists.R Class-SDMXDimension.R
        Class-SDMXTimeDimension.R Class-SDMXPrimaryMeasure.R
        Class-SDMXAttribute.R Class-SDMXComponents.R
        Class-SDMXDataStructure.R Class-SDMXDataStructures.R
        Class-SDMXOrganisation.R Class-SDMXAgency.R
        Class-SDMXItemScheme.R Class-SDMXOrganisationScheme.R
        Class-SDMXAgencyScheme.R Class-SDMXOrganisationSchemes.R
        Class-SDMXDataStructureDefinition.R Class-SDMXData.R
        Class-SDMXGenericData.R Class-SDMXCompactData.R
        Class-SDMXUtilityData.R Class-SDMXStructureSpecificData.R
        Class-SDMXStructureSpecificTimeSeriesData.R
        Class-SDMXCrossSectionalData.R Class-SDMXMessageGroup.R
        Class-SDMXDataFlow.R Class-SDMXDataFlows.R
        Class-SDMXRequestParams.R Class-SDMXRequestBuilder.R
        Class-SDMXREST20RequestBuilder.R
        Class-SDMXREST21RequestBuilder.R
        Class-SDMXDotStatRequestBuilder.R Class-SDMXServiceProvider.R
        Class-SDMXServiceProviders.R SDMXSchema-methods.R
        SDMXType-methods.R SDMXStructureType-methods.R
        SDMXHeader-methods.R SDMXFooterMessage-methods.R
        SDMXFooter-methods.R SDMX-methods.R SDMXConcept-methods.R
        SDMXConceptScheme-methods.R SDMXConcepts-methods.R
        SDMXCode-methods.R SDMXCodelist-methods.R
        SDMXCodelists-methods.R SDMXDimension-methods.R
        SDMXTimeDimension-methods.R SDMXPrimaryMeasure-methods.R
        SDMXAttribute-methods.R SDMXComponents-methods.R
        SDMXDataStructure-methods.R SDMXDataStructures-methods.R
        SDMXOrganisation-methods.R SDMXAgency-methods.R
        SDMXAgencyScheme-methods.R SDMXOrganisationSchemes-methods.R
        SDMXDataStructureDefinition-methods.R SDMXData-methods.R
        SDMXGenericData-methods.R SDMXCompactData-methods.R
        SDMXUtilityData-methods.R SDMXStructureSpecificData-methods.R
        SDMXStructureSpecificTimeSeriesData-methods.R
        SDMXCrossSectionalData-methods.R SDMXMessageGroup-methods.R
        SDMXDataFlow-methods.R SDMXDataFlows-methods.R
        SDMXRequestParams-methods.R SDMXRequestBuilder-methods.R
        SDMXREST20RequestBuilder-methods.R
        SDMXREST21RequestBuilder-methods.R
        SDMXDotStatRequestBuilder-methods.R
        SDMXServiceProvider-methods.R SDMXServiceProviders-methods.R
        readSDMX.R saveSDMX.R profile.R rsdmx.R
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2025-02-27 09:56:17 UTC; emman
Author: Emmanuel Blondel [aut, cre] (<https://orcid.org/0000-0002-5870-5762>),
  Matthieu Stigler [ctb] (<https://orcid.org/0000-0002-6802-4290>),
  Eric Persson [ctb]
Repository: CRAN
Date/Publication: 2025-02-27 11:00:05 UTC
Built: R 4.6.0; ; 2026-04-28 02:37:24 UTC; unix
