# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,SDMXCodelists)
S3method(as.data.frame,SDMXCompactData)
S3method(as.data.frame,SDMXComponents)
S3method(as.data.frame,SDMXConcepts)
S3method(as.data.frame,SDMXCrossSectionalData)
S3method(as.data.frame,SDMXDataFlows)
S3method(as.data.frame,SDMXDataStructures)
S3method(as.data.frame,SDMXGenericData)
S3method(as.data.frame,SDMXMessageGroup)
S3method(as.data.frame,SDMXOrganisationSchemes)
S3method(as.data.frame,SDMXServiceProviders)
S3method(as.data.frame,SDMXStructureSpecificData)
S3method(as.data.frame,SDMXStructureSpecificTimeSeriesData)
S3method(as.data.frame,SDMXUtilityData)
export(SDMX)
export(SDMXAgency)
export(SDMXAgencyScheme)
export(SDMXAttribute)
export(SDMXCode)
export(SDMXCodelist)
export(SDMXCodelists)
export(SDMXCompactData)
export(SDMXComponents)
export(SDMXConcept)
export(SDMXConceptScheme)
export(SDMXConcepts)
export(SDMXCrossSectionalData)
export(SDMXData)
export(SDMXDataFlow)
export(SDMXDataFlows)
export(SDMXDataStructure)
export(SDMXDataStructureDefinition)
export(SDMXDataStructures)
export(SDMXDimension)
export(SDMXDotStatRequestBuilder)
export(SDMXFooter)
export(SDMXFooterMessage)
export(SDMXGenericData)
export(SDMXHeader)
export(SDMXMessageGroup)
export(SDMXOrganisation)
export(SDMXOrganisationSchemes)
export(SDMXPrimaryMeasure)
export(SDMXREST20RequestBuilder)
export(SDMXREST21RequestBuilder)
export(SDMXRequestBuilder)
export(SDMXRequestParams)
export(SDMXSchema)
export(SDMXServiceProvider)
export(SDMXServiceProviders)
export(SDMXStructureSpecificData)
export(SDMXStructureSpecificTimeSeriesData)
export(SDMXStructureType)
export(SDMXTimeDimension)
export(SDMXType)
export(SDMXUtilityData)
export(addSDMXServiceProvider)
export(findNamespace)
export(findSDMXServiceProvider)
export(getRegistryInterfaceResult)
export(getSDMXServiceProviders)
export(getSoapRequestResult)
export(getStructureType)
export(isRegistryInterfaceEnvelope)
export(isSoapRequestEnvelope)
export(readSDMX)
export(rsdmxLogger)
export(saveSDMX)
export(setSDMXServiceProviders)
import(R6)
import(XML)
import(httr)
import(methods)
import(plyr)
import(utils)
