#' @name rsdmx
#' @aliases rsdmx-package
#' @aliases rsdmx
#' 
#' @title Tools for Reading SDMX Data and Metadata
#' @description
#' RSDMX is a package to parse/read SDMX documents in R. It provides:
#' - a set of classes and methods to read data and metadata documents exchanged 
#' through theStatistical Data and Metadata Exchange (SDMX) framework. The package 
#' currently focuses on the SDMX XML standard format (SDMX-ML).
#' - an web-service interface to well-known SDMX data providers
#' 
#' @import R6
#' @import methods
#' @import XML
#' @import httr
#' @import plyr
#' @import utils
#'  
#'@author Emmanuel Blondel \email{emmanuel.blondel1@@gmail.com}
#'
"_PACKAGE"